==> CGFeedMaker-1.0.15.tar.gz: CGFeedMaker/lang/ext/nl_NL.php <==
<?php
$lang['addcategory'] = 'Voeg een nieuwe categorie toe';
$lang['addedit_feed'] = 'Toevoegen/Bewerken RSS Feed';
$lang['addfeed'] = 'Voeg een nieuwe Feed toe';
$lang['areyousure_delete'] = 'Weet u zeker dat u dit item wilt verwijderen?';
$lang['cancel'] = 'Annuleren';
$lang['categories'] = 'Categorie&euml;n';
$lang['current_value'] = 'Huidige waarde';
$lang['delete'] = 'Verwijderen';
$lang['details'] = 'Details ';
$lang['edit'] = 'Bewerken';
$lang['error_missingparam'] = 'Een verplichte parameter of waarde is niet gevonden';
$lang['error_nameexists'] = 'Een artikel met deze naam bestaat reeds';
$lang['error_nocatname'] = 'Specificeer een categorienaam';
$lang['error_nonamegiven'] = 'U moet een feed naam of alias invoeren';
$lang['error_nopermission'] = 'Toegang geweigerd';
$lang['error_notemplate'] = 'Geen sjabloon opgegeven';
$lang['feeds'] = 'Feeds ';
$lang['feed_copyright'] = 'Feed Copyright ';
$lang['feed_description'] = 'Feed Omschrijving';
$lang['feed_editor'] = 'Feed Editor ';
$lang['feed_extension'] = 'Feed Extensie';
$lang['feed_image'] = 'Feed Afbeelding';
$lang['feed_link'] = 'Feed Link ';
$lang['feed_namealias'] = 'Feed Naam/Alias';
$lang['feed_pageid'] = 'Gebruik deze pagina voor links';
$lang['feed_title'] = 'Feed Titel';
$lang['feed_ttl'] = 'Levensduur';
$lang['friendlyname'] = 'Calguy&#039;s Feed Maker ';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module provides the ability to build and manage RSS Feeds consisting of data from any CMS Made Simple module that supports a summary view.</p>
<p>It supports categorizing the feeds, generating auto-discovery links, and standalone links to rss feeds.</p>
<p>Pretty URL&#039;s are supported if your site has them enabled. - <em>ex:</em> http://www.yoursite.com/feeds/Feed-Name</p>
<h3>How Do I Use It?</h3>
<ul>
<li>-First you must create a new feed, and fill in the parameters supplied.
  <p>A template is associated with each feed.  The default template illustrates how to generate an RSS feed from the News module</p>
  <p>To generate templates from other feeds you will need to use the template variables from that module. Put {get_template_vars} in a page that uses that module to see which variables you can call into your Feed Template. To control the output of your feed you need to use a combination of these template variables and modify your module call in the template.</p>
</li>
<li>-Secondly you should place an auto-discovery tag in the appropriate place.
  <p>This will create auto-discovery links in your output.  You can place this tag in the head section of the page template, or the metadata section of specific pages to generate autodiscovery.  Various parameters can be specified to control which feeds auto-discovery links are generated for.<br /></p>
<p>  
<em>ex1:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; feed=&#039;myFeed1,myFeed2 &#039;}</strong> - This creates autodiscovery links for all specified feeds<br />
<em>ex2:</em> <strong>{CGFeedMaker action=&#039;autodiscovery&#039; category=&#039;myCategory1,myCategory2&#039;}</strong> - This creates autodiscovery links for all feeds in the specified category or categories</p>
</li>
  <li>-Thirdly, you can place links to specific feeds in your content.  using the action=rsslink parameter.<p>This will create a link to the specified feed in the location you put the call.</p>
  <p><em>ex1:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039;}</strong> - Generic &quot;rsslink&quot; call
  <br/>
  <em>ex2:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; imageonly=&#039;&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039;}</strong> - This call displays a link that shows only an Image for the link, it specifies a different image that was uploaded to use for the link than the default image and it uses a different CSS class to format the image (specified in one of your stylesheets)  
  <br />
   <em>ex3:</em> <strong>{CGFeedMaker action=&#039;rsslink&#039; feed=&#039;myfeed&#039; text=&#039;RSS News Feed&#039; image=&#039;uploads/images/rssNew.jpg&#039; imageclass=&#039;rssImage&#039; linkclass=&quot;rssLink&quot;}</strong> - This call specifies different text for the link to the feed, specifies a new image to be used and uses different CSS classes to format the Image and Link (specified in one of your stylesheets)   </p> 
  </ul>
<h3>Notes:</h3>
<ul>
<li>This module will work best, and the default feeds will validate if you have configured pretty urls properly.   Otherwise, atom links seem to have problems with some of our URLS.</li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
';
$lang['info_alias'] = 'Deze feed mag alleen karakters bevatten, die toepasbaar zijn in een url';
$lang['info_copyright'] = 'Copyright bericht voor de inhoud van dit kanaal';
$lang['info_description'] = 'Een naam of beschrijving die dit kanaal benoemd';
$lang['info_editor'] = 'Email adres van de beheerder van dit kanaal';
$lang['info_extension'] = 'Feed Extentie (specificeer een extentie voor deze feed, bijv. xml, rss, kml... Als deze waarde niet is gespecificeerd, dan zal de standaard RSS extentie worden toegepast';
$lang['info_feed_extension'] = 'Wanneer mod_rewrite wordt toegepast om pretty url&#039;s te maken kan deze parameter worden gebruikt om de extensie van de feed te benoemen.';
$lang['info_image'] = 'Benoem een GIF, JPEG or PNG afbeelding die bij het kanaal zal worden getoond';
$lang['info_link'] = 'De URL van de HTML website van dit kanaal';
$lang['info_pageid'] = 'De pagina die wordt gebruikt voor alle link&#039;s in deze feed';
$lang['info_ttl'] = 'Het aantal minuten dat weergeeft hoe lang een kanaal gecached kan worden voordat hij refresht (ververst) vanaf de bron.';
$lang['moddescription'] = 'Een flexibel stukje gereedschap voor het maken en beheren van RSS feeds';
$lang['name'] = 'Naam';
$lang['param_action'] = 'Specify the behaviour of the module. There are two possible values for this parameter &quot;autodiscovery&quot; &amp; &quot;rsslink&quot;. The autodiscovery action will generate auto discovery links, and should be used in a place that would result in the resulting content appearing in the head section of your output. The rsslink action can be used to create a link to a specific feed, and can be placed in your page content';
$lang['param_category'] = 'Useful only with the autodiscovery action, this parameter allows you to specify a comma separated list of feed categories that will control which feeds links are generated for';
$lang['param_feed'] = 'Useful in the rsslink and autodiscovery action, this parameter allows you to specify which feed to generate a link for. When in the autodiscovery action, a comma separated list of feed names can be supplied.';
$lang['param_image'] = 'Deze parameter geeft je de mogelijkheid om verschillende plaatjes per link te specificeren.';
$lang['param_imageclass'] = 'Benoem een CSS class om de vertoning van de image tag van een rss feed link te stijlen';
$lang['param_imageonly'] = 'Bruikbaar in de rsslink actie. Met deze parameter kun je aangeven dat er geen tekst bij de link wordt weergegeven';
$lang['param_linkclass'] = 'Benoem een CSS class om de vertoning van de link tag van een rss feed link te stijlen';
$lang['param_urlonly'] = 'Applicable only to the rsslink action, this parameter requests that the code only output the url to the RSS feed ';
$lang['param_text'] = 'Bruikbaar in de rsslink actie. Met deze parameter kun je aangeven welke tekst je wilt associeren met de link. Wanneer je deze parameter niet specificeert, zal de titel van de feed worden toegepast.';
$lang['postinstall'] = 'De CGFeedMaker Module is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'De CGFeedMaker Module, en alle bijbehorende data is verwijderd';
$lang['really_uninstall'] = 'Weet u zeker dat u deze module wilt verwijderen?  Alle bijbehorende data van deze module zal ook worden verwijderd';
$lang['reset_to_factory'] = 'Terug naar standaard instellingen';
$lang['settings'] = 'Instellingen';
$lang['submit'] = 'Verzenden';
$lang['template'] = 'Sjabloon';
$lang['template_source'] = 'Sjabloon Bron';
$lang['utma'] = '156861353.1738896039.1278840000.1280305238.1280321680.54';
$lang['utmz'] = '156861353.1280218995.48.5.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,13.0.html';
$lang['qca'] = 'P0-854387043-1278840000917';
$lang['utmb'] = '156861353.6.10.1280321680';
$lang['utmc'] = '156861353';
?>

==> CGFeedMaker-1.0.19.tar.gz: CGFeedMaker/lang/ext/nl_NL.php <==
<?php
$lang['addcategory'] = 'Voeg een nieuwe categorie toe';
$lang['addedit_feed'] = 'Toevoegen/Bewerken RSS Feed';
$lang['addfeed'] = 'Voeg een nieuwe Feed toe';
$lang['areyousure_delete'] = 'Weet u zeker dat u dit item wilt verwijderen?';
$lang['cancel'] = 'Annuleren';
$lang['categories'] = 'Categorie&euml;n';
$lang['current_value'] = 'Huidige waarde';
$lang['delete'] = 'Verwijderen';
$lang['details'] = 'Details ';
$lang['edit'] = 'Bewerken';
$lang['error_missingparam'] = 'Een verplichte parameter of waarde is niet gevonden';
$lang['error_nameexists'] = 'Een artikel met deze naam bestaat reeds';
$lang['error_nocatname'] = 'Specificeer een categorienaam';
$lang['error_nonamegiven'] = 'U moet een feed naam of alias invoeren';
$lang['error_nopermission'] = 'Toegang geweigerd';
$lang['error_notemplate'] = 'Geen sjabloon opgegeven';
$lang['feeds'] = 'Feeds ';
$lang['feed_copyright'] = 'Feed Copyright ';
$lang['feed_description'] = 'Feed Omschrijving';
$lang['feed_editor'] = 'Feed Editor ';
$lang['feed_extension'] = 'Feed Extensie';
$lang['feed_image'] = 'Feed Afbeelding';
$lang['feed_link'] = 'Feed Link ';
$lang['feed_namealias'] = 'Feed Naam/Alias';
$lang['feed_pageid'] = 'Gebruik deze pagina voor links';
$lang['feed_title'] = 'Feed Titel';
$lang['feed_ttl'] = 'Levensduur';
$lang['feed_url'] = 'Feed Url';
$lang['friendlyname'] = 'Calguy&#039;s Feed Maker ';
$lang['info_alias'] = 'Deze feed mag alleen karakters bevatten, die toepasbaar zijn in een url';
$lang['info_copyright'] = 'Copyright bericht voor de inhoud van dit kanaal';
$lang['info_description'] = 'Een naam of beschrijving die dit kanaal benoemd';
$lang['info_editor'] = 'Email adres van de beheerder van dit kanaal';
$lang['info_extension'] = 'Feed Extentie (specificeer een extentie voor deze feed, bijv. xml, rss, kml... Als deze waarde niet is gespecificeerd, dan zal de standaard RSS extentie worden toegepast';
$lang['info_feed_extension'] = 'Wanneer mod_rewrite wordt toegepast om pretty url&#039;s te maken kan deze parameter worden gebruikt om de extensie van de feed te benoemen.';
$lang['info_image'] = 'Benoem een GIF, JPEG or PNG afbeelding die bij het kanaal zal worden getoond';
$lang['info_link'] = 'De URL van de HTML website van dit kanaal';
$lang['info_pageid'] = 'De pagina die wordt gebruikt voor alle link&#039;s in deze feed';
$lang['info_ttl'] = 'Het aantal minuten dat weergeeft hoe lang een kanaal gecached kan worden voordat hij refresht (ververst) vanaf de bron.';
$lang['moddescription'] = 'Een flexibel stukje gereedschap voor het maken en beheren van RSS feeds';
$lang['name'] = 'Naam';
$lang['param_action'] = 'Specify the behaviour of the module. There are two possible values for this parameter &quot;autodiscovery&quot; &amp; &quot;rsslink&quot;. The autodiscovery action will generate auto discovery links, and should be used in a place that would result in the resulting content appearing in the head section of your output. The rsslink action can be used to create a link to a specific feed, and can be placed in your page content';
$lang['param_category'] = 'Useful only with the autodiscovery action, this parameter allows you to specify a comma separated list of feed categories that will control which feeds links are generated for';
$lang['param_feed'] = 'Useful in the rsslink and autodiscovery action, this parameter allows you to specify which feed to generate a link for. When in the autodiscovery action, a comma separated list of feed names can be supplied.';
$lang['param_image'] = 'Deze parameter geeft je de mogelijkheid om verschillende plaatjes per link te specificeren.';
$lang['param_imageclass'] = 'Benoem een CSS class om de vertoning van de image tag van een rss feed link te stijlen';
$lang['param_imageonly'] = 'Bruikbaar in de rsslink actie. Met deze parameter kun je aangeven dat er geen tekst bij de link wordt weergegeven';
$lang['param_linkclass'] = 'Benoem een CSS class om de vertoning van de link tag van een rss feed link te stijlen';
$lang['param_urlonly'] = 'Applicable only to the rsslink action, this parameter requests that the code only output the url to the RSS feed ';
$lang['param_text'] = 'Bruikbaar in de rsslink actie. Met deze parameter kun je aangeven welke tekst je wilt associeren met de link. Wanneer je deze parameter niet specificeert, zal de titel van de feed worden toegepast.';
$lang['postinstall'] = 'De CGFeedMaker Module is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'De CGFeedMaker Module, en alle bijbehorende data is verwijderd';
$lang['really_uninstall'] = 'Weet u zeker dat u deze module wilt verwijderen?  Alle bijbehorende data van deze module zal ook worden verwijderd';
$lang['reset_to_factory'] = 'Terug naar standaard instellingen';
$lang['settings'] = 'Instellingen';
$lang['submit'] = 'Verzenden';
$lang['template'] = 'Sjabloon';
$lang['template_source'] = 'Sjabloon Bron';
$lang['utma'] = '156861353.421479005.1352744060.1352744060.1352744060.1';
$lang['utmz'] = '156861353.1352744060.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
